"use strict";
var ts = require("typescript");
var fs = require("fs");
var path = require("path");
var babel = require("babel-core");
var basePath = process.cwd();
var tsConfigPath = path.join(basePath, "tsconfig.json");
fs.readFile(tsConfigPath, "utf8", function (readError, data) {
    if (readError != null) {
        throw readError;
    }
    var _a = ts.parseConfigFileTextToJson(tsConfigPath, data), config = _a.config, error = _a.error;
    if (error == null || !printErrors([error])) {
        config.noEmitOnError = false;
        compile(config);
    }
});
function compile(config) {
    var compilerOptions = ts.convertCompilerOptionsFromJson(config.compilerOptions, basePath);
    if (printErrors(compilerOptions.errors)) {
        return;
    }
    var program = ts.createProgram(config.files, compilerOptions.options);
    if (printErrors(ts.getPreEmitDiagnostics(program))) {
        return;
    }
    var outDir = compilerOptions.options.outDir;
    if (outDir == null) {
        throw new Error("outDir is not specified in the compilerOptions");
    }
    var fileToSourceMap = {};
    program.emit(undefined, function (fileName, data) {
        if (endsWith(fileName, ".js")) {
            var sourceMapFileName = fileName + ".map";
            processCompiled(data, fileToSourceMap[sourceMapFileName], fileName, sourceMapFileName);
        }
        else if (endsWith(fileName, ".js.map")) {
            fileToSourceMap[fileName] = data;
        }
    });
}
function processCompiled(code, sourceMap, jsFileName, sourceMapFileName) {
    var result = babel.transform(code, {
        inputSourceMap: JSON.parse(sourceMap),
        sourceMaps: true,
        filename: jsFileName,
    });
    var handler = function (e) { if (e != null)
        throw e; };
    fs.writeFile(jsFileName, result.code, handler);
    fs.writeFile(sourceMapFileName, JSON.stringify(result.map), handler);
}
function printErrors(errors) {
    if (errors.length === 0) {
        return false;
    }
    for (var _i = 0, errors_1 = errors; _i < errors_1.length; _i++) {
        var diagnostic = errors_1[_i];
        var _a = diagnostic.file.getLineAndCharacterOfPosition(diagnostic.start), line = _a.line, character = _a.character;
        var message = ts.flattenDiagnosticMessageText(diagnostic.messageText, '\n');
        console.log(diagnostic.file.fileName + " (" + (line + 1) + "," + (character + 1) + "): " + message);
    }
    process.exit(1);
    return true;
}
function endsWith(subjectString, searchString) {
    var position = subjectString.length - searchString.length;
    var lastIndex = subjectString.indexOf(searchString, position);
    return lastIndex !== -1 && lastIndex === position;
}
//# sourceMappingURL=builder.js.map